<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="fr_FR" sourcelanguage="en_US">
<context>
    <name>mainwindow</name>
    <message>
        <source>CSSU Tuner</source>
        <translation>CSSU Tuner</translation>
    </message>
    <message>
        <source>Transitions lenght (ms)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Status menu rows</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Status menu rows
(portait)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Always show FM-applet</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>App menu editing Enabled</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Homescreen editing Enabled</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Ultra fast Transitions</source>
        <translation>Transitions Ultra Rapides</translation>
    </message>
    <message>
        <source>Fast Transitions</source>
        <translation>Transitions Rapides</translation>
    </message>
    <message>
        <source>Normal Transitions</source>
        <translation>Transitions Normales</translation>
    </message>
    <message>
        <source>Slow Transitions</source>
        <translation>Transitions Lentes</translation>
    </message>
    <message>
        <source>Turtle Transitions</source>
        <translation>Transitions Ultra Lentes</translation>
    </message>
    <message>
        <source>Default style Task Switcher</source>
        <translation>Gestionnaire de tâches, style par défaut</translation>
    </message>
    <message>
        <source>Single column Task Switcher</source>
        <translation>Gestionnaire de tâches, style 1 colonne</translation>
    </message>
    <message>
        <source>Double columns Task Switcher</source>
        <translation>Gestionnaire de tâches, style 2 colonnes</translation>
    </message>
    <message>
        <source>App menu blur</source>
        <translation>Flou du Menu Apllication</translation>
    </message>
    <message>
        <source>App menu scroll speed</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Parallax</source>
        <translation>Parallaxe</translation>
    </message>
    <message>
        <source>Blurless saturation Enabled</source>
        <translation>Activer la saturation du Noir et Blanc</translation>
    </message>
    <message>
        <source>Force rotation Enabled</source>
        <translation>Activer la rotation forcée</translation>
    </message>
    <message>
        <source>Rotate around z-axis Enabled</source>
        <translation>Activer la Rotation sur l&apos;axe Z</translation>
    </message>
    <message>
        <source>Tactile feedback Enabled</source>
        <translation>Activer le retour dé l&apos;écran tactile</translation>
    </message>
    <message>
        <source>Zoom on press Enabled</source>
        <translation>Activer le zoom quand on presse</translation>
    </message>
    <message>
        <source>About</source>
        <translation>A propos</translation>
    </message>
    <message>
        <source>Save</source>
        <translation>Sauvegarder</translation>
    </message>
    <message>
        <source>Author: d-iivil&lt;br /&gt;Licence: GPL</source>
        <translation>Autheur: d-iivil&lt;br /&gt;Licence: GPL&lt;br /&gt;Traduction: GaRy delaMer</translation>
    </message>
    <message>
        <source>version</source>
        <translation>version</translation>
    </message>
    <message>
        <source>Transitions updated!</source>
        <translation>Transisitons mises à jour!</translation>
    </message>
    <message>
        <source>Reboot is required to activate all changes.</source>
        <translation>Le redémarrage est nécessaire pour activer tous les changements.</translation>
    </message>
</context>
</TS>
